@@ -31,6 +31,8 @@ _R_SHACL_NODE_PROP = URIRef(_SHACL_NAMESPACE + "node")
 
 _R_SHACL_IN_PROP = URIRef(_SHACL_NAMESPACE + "in")
 
+_R_SHACL_PATTERN_PROP = URIRef(_SHACL_NAMESPACE + "pattern")
+
 _R_SHACL_NODEKIND_IRI = URIRef(_SHACL_NAMESPACE + "IRI")
 _R_SHACL_NODEKIND_LITERAL = URIRef(_SHACL_NAMESPACE + "Literal")
 _R_SHACL_NODEKIND_BNODE = URIRef(_SHACL_NAMESPACE + "BlankNode")
@@ -50,13 +52,15 @@ _MACRO_MAPPING = {IRI_ELEM_TYPE: _R_SHACL_NODEKIND_IRI,
 class ShaclSerializer(object):
 
     def __init__(self, target_file, shapes_list, namespaces_dict=None, string_return=False,
-                 instantiation_property_str=RDF_TYPE_STR, wikidata_annotation=False):
+                 instantiation_property_str=RDF_TYPE_STR, wikidata_annotation=False,
+                 detect_minimal_iri=False):
         self._target_file = target_file
         self._namespaces_dict = namespaces_dict if namespaces_dict is not None else {}
         self._shapes_list = shapes_list
         self._string_return = string_return
         self._instantiation_property_str = instantiation_property_str
         self._wikidata_annotation = wikidata_annotation
+        self._detect_minimal_iri=detect_minimal_iri
 
         self._g_shapes = Graph()
 
@@ -113,15 +117,27 @@ class ShaclSerializer(object):
         self._add_shape_uri(r_shape_uri=r_shape_uri)
         self._add_target_class(r_shape_uri=r_shape_uri,
                                shape=shape)
+        self._add_min_iri(r_shape_uri=r_shape_uri,
+                          shape=shape)
         self._add_shape_constraints(shape=shape,
                                     r_shape_uri=r_shape_uri)
 
+
     def _add_target_class(self, shape, r_shape_uri):
         if shape.class_uri is not None:
             self._add_triple(r_shape_uri,
                              _R_SHACL_TARGET_CLASS_PROP,
                              URIRef(shape.class_uri))  # TODO check if this is always an abs. URI, not sure
 
+    def _add_min_iri (self, shape, r_shape_uri):
+        if shape.iri_pattern is not None:
+            self._add_triple(r_shape_uri,
+                             _R_SHACL_PATTERN_PROP,
+                             self._literal_iri_pattern(shape))
+
+    def _literal_iri_pattern(self, shape):
+        return Literal("^{}".format(shape.iri_pattern))
+
     def _add_shape_constraints(self, shape, r_shape_uri):
         for a_statement in shape.yield_statements():
             self._add_constraint(statement=a_statement,
